pub fn black_box<T>(dummy: T) -> T👎Deprecated:
use std::hint::black_box() instead
A function that is opaque to the optimizer, used to prevent the compiler from optimizing away computations in a benchmark.